@@ -1,25 +1,26 @@
 """
 """
 
-from untwisted.network import core, Spin, xmap
-from untwisted.iostd import create_server, ACCEPT, CLOSE, lose
+from untwisted.server import create_server
+from untwisted.event import ACCEPT, CLOSE
 from untwisted.splits import Terminator
 from untwisted.tools import coroutine
+from untwisted import core
 
 class ChatServer:
     def __init__(self, server):
-        xmap(server, ACCEPT, self.handle_accept)
+        server.add_map(ACCEPT, self.handle_accept)
         self.pool = []
 
     @coroutine
     def handle_accept(self, server, client):
         Terminator(client, delim=b'\r\n')
-        xmap(client, CLOSE, lambda client, err: self.pool.remove(client))
+        client.add_map(CLOSE, lambda client, err: self.pool.remove(client))
 
         client.dump(b'Type a nick.\r\nNick:')    
         client.nick, = yield client, Terminator.FOUND
 
-        xmap(client, Terminator.FOUND, self.echo_msg)
+        client.add_map(Terminator.FOUND, self.echo_msg)
         self.pool.append(client)
 
     def echo_msg(self, client, data):
