@@ -5,7 +5,7 @@ from untwisted.dispatcher import Erase
 from untwisted.sock_writer import SockWriter, SockWriterSSL
 from untwisted.sock_reader import SockReader, SockReaderSSL
 from untwisted.network import SuperSocket
-from untwisted.network import SSL
+from untwisted.network import SuperSocketSSL
 
 import socket
 import ssl
@@ -27,7 +27,7 @@ class Client:
         else:
             ssock.drive(CONNECT)
 
-class Handshake:
+class ClientHandshake:
     """ 
     """
 
@@ -40,17 +40,14 @@ class Handshake:
 
         try:
             ssock.do_handshake()
-        except ssl.CertificateError as excpt:
-            ssock.drive(SSL_CERTIFICATE_ERR, excpt)
         except ssl.SSLWantReadError:
             pass
         except ssl.SSLWantWriteError:
             pass
-        except socket.error as excpt:
-            # When it happens then it should spawn SSL_CONNECT_ERR.
-            ssock.drive(SSL_CONNECT_ERR, excpt)
         except ssl.SSLError as excpt:
             ssock.drive(SSL_CONNECT_ERR, excpt)
+        except socket.error as excpt:
+            ssock.drive(SSL_CONNECT_ERR, excpt)
         else:
             ssock.drive(SSL_CONNECT)
             raise Erase
@@ -66,7 +63,7 @@ class ClientSSL:
 
     def update(self, ssock):
         ssock.del_map(CONNECT, self.update)
-        Handshake(ssock)
+        ClientHandshake(ssock)
 
 def lose(ssock):
     """
@@ -126,7 +123,8 @@ def create_client_ssl(addr, port):
     """
     Shorthand function to set up a SSL connection. It installs all necessary
     extensions to send and receive data over a secured connection.
-    
+
+    This helper function creates a ssl socket with a default context.    
     It also deals with CLOSE event properly.
     """
 
@@ -138,7 +136,7 @@ def create_client_ssl(addr, port):
     # First attempt to connect otherwise it leaves
     # an unconnected ssock instance in the reactor.
     wrap.connect_ex((addr, port))
-    con = SSL(wrap)
+    con = SuperSocketSSL(wrap)
 
     ClientSSL(con)
     con.add_map(SSL_CONNECT, install_ssl_handles)
