@@ -74,3 +74,8 @@ class SSL_CONNECT_ERR(Event):
 class SSL_CONNECT(Event):         
     pass
 
+class SSL_ACCEPT(Event):         
+    pass
+
+class SSL_ACCEPT_ERR(Event):
+    pass
